@@ -13,11 +13,11 @@ Usage::
     client: IAMRolesAnywhereClient = session.client("rolesanywhere")
     ```
 """
+
 import sys
-from typing import IO, Any, Dict, Mapping, Sequence, Type, Union, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
-from botocore.response import StreamingBody
 
 from .paginator import (
     ListCrlsPaginator,
@@ -26,20 +26,25 @@ from .paginator import (
     ListTrustAnchorsPaginator,
 )
 from .type_defs import (
+    BlobTypeDef,
     CrlDetailResponseTypeDef,
     ListCrlsResponseTypeDef,
     ListProfilesResponseTypeDef,
     ListSubjectsResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
     ListTrustAnchorsResponseTypeDef,
+    NotificationSettingKeyTypeDef,
+    NotificationSettingTypeDef,
     ProfileDetailResponseTypeDef,
+    PutNotificationSettingsResponseTypeDef,
+    ResetNotificationSettingsResponseTypeDef,
     SourceTypeDef,
     SubjectDetailResponseTypeDef,
     TagTypeDef,
     TrustAnchorDetailResponseTypeDef,
 )
 
-if sys.version_info >= (3, 9):
+if sys.version_info >= (3, 12):
     from typing import Literal
 else:
     from typing_extensions import Literal
@@ -48,7 +53,7 @@ else:
 __all__ = ("IAMRolesAnywhereClient",)
 
 
-class BotocoreClientError(BaseException):
+class BotocoreClientError(Exception):
     MSG_TEMPLATE: str
 
     def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
@@ -110,7 +115,9 @@ class IAMRolesAnywhereClient(BaseClient):
         tags: Sequence[TagTypeDef] = ...
     ) -> ProfileDetailResponseTypeDef:
         """
-        Creates a profile.
+        Creates a *profile*, a list of the roles that Roles Anywhere service is trusted
+        to
+        assume.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rolesanywhere.html#IAMRolesAnywhere.Client.create_profile)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rolesanywhere/client/#create_profile)
@@ -122,10 +129,13 @@ class IAMRolesAnywhereClient(BaseClient):
         name: str,
         source: SourceTypeDef,
         enabled: bool = ...,
+        notificationSettings: Sequence[NotificationSettingTypeDef] = ...,
         tags: Sequence[TagTypeDef] = ...
     ) -> TrustAnchorDetailResponseTypeDef:
         """
-        Creates a trust anchor.
+        Creates a trust anchor to establish trust between IAM Roles Anywhere and your
+        certificate authority
+        (CA).
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rolesanywhere.html#IAMRolesAnywhere.Client.create_trust_anchor)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rolesanywhere/client/#create_trust_anchor)
@@ -189,9 +199,7 @@ class IAMRolesAnywhereClient(BaseClient):
 
     def enable_profile(self, *, profileId: str) -> ProfileDetailResponseTypeDef:
         """
-        Enables the roles in a profile to receive session credentials in
-        [CreateSession](https://docs.aws.amazon.com/rolesanywhere/latest/APIReference/API_CreateSession.html)_
-        .
+        Enables temporary credential requests for a profile.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rolesanywhere.html#IAMRolesAnywhere.Client.enable_profile)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rolesanywhere/client/#enable_profile)
@@ -237,7 +245,8 @@ class IAMRolesAnywhereClient(BaseClient):
 
     def get_subject(self, *, subjectId: str) -> SubjectDetailResponseTypeDef:
         """
-        Gets a Subject.
+        Gets a *subject*, which associates a certificate identity with authentication
+        attempts.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rolesanywhere.html#IAMRolesAnywhere.Client.get_subject)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rolesanywhere/client/#get_subject)
@@ -254,7 +263,7 @@ class IAMRolesAnywhereClient(BaseClient):
     def import_crl(
         self,
         *,
-        crlData: Union[str, bytes, IO[Any], StreamingBody],
+        crlData: BlobTypeDef,
         name: str,
         trustAnchorArn: str,
         enabled: bool = ...,
@@ -269,7 +278,9 @@ class IAMRolesAnywhereClient(BaseClient):
 
     def list_crls(self, *, nextToken: str = ..., pageSize: int = ...) -> ListCrlsResponseTypeDef:
         """
-        Lists all Crls in the authenticated account and Amazon Web Services Region.
+        Lists all certificate revocation lists (CRL) in the authenticated account and
+        Amazon Web Services
+        Region.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rolesanywhere.html#IAMRolesAnywhere.Client.list_crls)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rolesanywhere/client/#list_crls)
@@ -314,6 +325,29 @@ class IAMRolesAnywhereClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rolesanywhere/client/#list_trust_anchors)
         """
 
+    def put_notification_settings(
+        self, *, notificationSettings: Sequence[NotificationSettingTypeDef], trustAnchorId: str
+    ) -> PutNotificationSettingsResponseTypeDef:
+        """
+        Attaches a list of *notification settings* to a trust anchor.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rolesanywhere.html#IAMRolesAnywhere.Client.put_notification_settings)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rolesanywhere/client/#put_notification_settings)
+        """
+
+    def reset_notification_settings(
+        self,
+        *,
+        notificationSettingKeys: Sequence[NotificationSettingKeyTypeDef],
+        trustAnchorId: str
+    ) -> ResetNotificationSettingsResponseTypeDef:
+        """
+        Resets the *custom notification setting* to IAM Roles Anywhere default setting.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rolesanywhere.html#IAMRolesAnywhere.Client.reset_notification_settings)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rolesanywhere/client/#reset_notification_settings)
+        """
+
     def tag_resource(self, *, resourceArn: str, tags: Sequence[TagTypeDef]) -> Dict[str, Any]:
         """
         Attaches tags to a resource.
@@ -331,11 +365,7 @@ class IAMRolesAnywhereClient(BaseClient):
         """
 
     def update_crl(
-        self,
-        *,
-        crlId: str,
-        crlData: Union[str, bytes, IO[Any], StreamingBody] = ...,
-        name: str = ...
+        self, *, crlId: str, crlData: BlobTypeDef = ..., name: str = ...
     ) -> CrlDetailResponseTypeDef:
         """
         Updates the certificate revocation list (CRL).
@@ -355,7 +385,9 @@ class IAMRolesAnywhereClient(BaseClient):
         sessionPolicy: str = ...
     ) -> ProfileDetailResponseTypeDef:
         """
-        Updates the profile.
+        Updates a *profile*, a list of the roles that IAM Roles Anywhere service is
+        trusted to
+        assume.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rolesanywhere.html#IAMRolesAnywhere.Client.update_profile)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rolesanywhere/client/#update_profile)
@@ -365,8 +397,7 @@ class IAMRolesAnywhereClient(BaseClient):
         self, *, trustAnchorId: str, name: str = ..., source: SourceTypeDef = ...
     ) -> TrustAnchorDetailResponseTypeDef:
         """
-        Updates the trust anchor.You establish trust between IAM Roles Anywhere and your
-        certificate authority (CA) by configuring a trust anchor.
+        Updates a trust anchor.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rolesanywhere.html#IAMRolesAnywhere.Client.update_trust_anchor)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rolesanywhere/client/#update_trust_anchor)
