@@ -11,9 +11,10 @@ Usage::
     data: ListCrlsPaginatorName = "list_crls"
     ```
 """
+
 import sys
 
-if sys.version_info >= (3, 9):
+if sys.version_info >= (3, 12):
     from typing import Literal
 else:
     from typing_extensions import Literal
@@ -24,6 +25,8 @@ __all__ = (
     "ListProfilesPaginatorName",
     "ListSubjectsPaginatorName",
     "ListTrustAnchorsPaginatorName",
+    "NotificationChannelType",
+    "NotificationEventType",
     "TrustAnchorTypeType",
     "IAMRolesAnywhereServiceName",
     "ServiceName",
@@ -37,6 +40,8 @@ ListCrlsPaginatorName = Literal["list_crls"]
 ListProfilesPaginatorName = Literal["list_profiles"]
 ListSubjectsPaginatorName = Literal["list_subjects"]
 ListTrustAnchorsPaginatorName = Literal["list_trust_anchors"]
+NotificationChannelType = Literal["ALL"]
+NotificationEventType = Literal["CA_CERTIFICATE_EXPIRY", "END_ENTITY_CERTIFICATE_EXPIRY"]
 TrustAnchorTypeType = Literal["AWS_ACM_PCA", "CERTIFICATE_BUNDLE", "SELF_SIGNED_REPOSITORY"]
 IAMRolesAnywhereServiceName = Literal["rolesanywhere"]
 ServiceName = Literal[
@@ -54,6 +59,7 @@ ServiceName = Literal[
     "apigatewayv2",
     "appconfig",
     "appconfigdata",
+    "appfabric",
     "appflow",
     "appintegrations",
     "application-autoscaling",
@@ -63,14 +69,21 @@ ServiceName = Literal[
     "apprunner",
     "appstream",
     "appsync",
+    "arc-zonal-shift",
     "athena",
     "auditmanager",
     "autoscaling",
     "autoscaling-plans",
+    "b2bi",
     "backup",
     "backup-gateway",
     "backupstorage",
     "batch",
+    "bcm-data-exports",
+    "bedrock",
+    "bedrock-agent",
+    "bedrock-agent-runtime",
+    "bedrock-runtime",
     "billingconductor",
     "braket",
     "budgets",
@@ -80,22 +93,29 @@ ServiceName = Literal[
     "chime-sdk-media-pipelines",
     "chime-sdk-meetings",
     "chime-sdk-messaging",
+    "chime-sdk-voice",
+    "cleanrooms",
+    "cleanroomsml",
     "cloud9",
     "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
+    "cloudfront-keyvaluestore",
     "cloudhsm",
     "cloudhsmv2",
     "cloudsearch",
     "cloudsearchdomain",
     "cloudtrail",
+    "cloudtrail-data",
     "cloudwatch",
     "codeartifact",
     "codebuild",
+    "codecatalyst",
     "codecommit",
     "codedeploy",
     "codeguru-reviewer",
+    "codeguru-security",
     "codeguruprofiler",
     "codepipeline",
     "codestar",
@@ -114,12 +134,14 @@ ServiceName = Literal[
     "connectcases",
     "connectparticipant",
     "controltower",
+    "cost-optimization-hub",
     "cur",
     "customer-profiles",
     "databrew",
     "dataexchange",
     "datapipeline",
     "datasync",
+    "datazone",
     "dax",
     "detective",
     "devicefarm",
@@ -129,6 +151,7 @@ ServiceName = Literal[
     "dlm",
     "dms",
     "docdb",
+    "docdb-elastic",
     "drs",
     "ds",
     "dynamodb",
@@ -141,6 +164,7 @@ ServiceName = Literal[
     "ecs",
     "efs",
     "eks",
+    "eks-auth",
     "elastic-inference",
     "elasticache",
     "elasticbeanstalk",
@@ -150,6 +174,7 @@ ServiceName = Literal[
     "emr",
     "emr-containers",
     "emr-serverless",
+    "entityresolution",
     "es",
     "events",
     "evidently",
@@ -161,9 +186,9 @@ ServiceName = Literal[
     "forecast",
     "forecastquery",
     "frauddetector",
+    "freetier",
     "fsx",
     "gamelift",
-    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -180,10 +205,13 @@ ServiceName = Literal[
     "imagebuilder",
     "importexport",
     "inspector",
+    "inspector-scan",
     "inspector2",
+    "internetmonitor",
     "iot",
     "iot-data",
     "iot-jobs-data",
+    "iot-roborunner",
     "iot1click-devices",
     "iot1click-projects",
     "iotanalytics",
@@ -198,26 +226,31 @@ ServiceName = Literal[
     "iottwinmaker",
     "iotwireless",
     "ivs",
+    "ivs-realtime",
     "ivschat",
     "kafka",
     "kafkaconnect",
     "kendra",
+    "kendra-ranking",
     "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
     "kinesis-video-signaling",
+    "kinesis-video-webrtc-storage",
     "kinesisanalytics",
     "kinesisanalyticsv2",
     "kinesisvideo",
     "kms",
     "lakeformation",
     "lambda",
+    "launch-wizard",
     "lex-models",
     "lex-runtime",
     "lexv2-models",
     "lexv2-runtime",
     "license-manager",
+    "license-manager-linux-subscriptions",
     "license-manager-user-subscriptions",
     "lightsail",
     "location",
@@ -227,10 +260,12 @@ ServiceName = Literal[
     "lookoutvision",
     "m2",
     "machinelearning",
-    "macie",
     "macie2",
     "managedblockchain",
+    "managedblockchain-query",
+    "marketplace-agreement",
     "marketplace-catalog",
+    "marketplace-deployment",
     "marketplace-entitlement",
     "marketplacecommerceanalytics",
     "mediaconnect",
@@ -238,9 +273,11 @@ ServiceName = Literal[
     "medialive",
     "mediapackage",
     "mediapackage-vod",
+    "mediapackagev2",
     "mediastore",
     "mediastore-data",
     "mediatailor",
+    "medical-imaging",
     "memorydb",
     "meteringmarketplace",
     "mgh",
@@ -254,15 +291,23 @@ ServiceName = Literal[
     "mturk",
     "mwaa",
     "neptune",
+    "neptunedata",
     "network-firewall",
     "networkmanager",
     "nimble",
+    "oam",
+    "omics",
     "opensearch",
+    "opensearchserverless",
     "opsworks",
     "opsworkscm",
     "organizations",
+    "osis",
     "outposts",
     "panorama",
+    "payment-cryptography",
+    "payment-cryptography-data",
+    "pca-connector-ad",
     "personalize",
     "personalize-events",
     "personalize-runtime",
@@ -271,10 +316,13 @@ ServiceName = Literal[
     "pinpoint-email",
     "pinpoint-sms-voice",
     "pinpoint-sms-voice-v2",
+    "pipes",
     "polly",
     "pricing",
     "privatenetworks",
     "proton",
+    "qbusiness",
+    "qconnect",
     "qldb",
     "qldb-session",
     "quicksight",
@@ -286,7 +334,9 @@ ServiceName = Literal[
     "redshift-data",
     "redshift-serverless",
     "rekognition",
+    "repostspace",
     "resiliencehub",
+    "resource-explorer-2",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -305,12 +355,16 @@ ServiceName = Literal[
     "sagemaker-a2i-runtime",
     "sagemaker-edge",
     "sagemaker-featurestore-runtime",
+    "sagemaker-geospatial",
+    "sagemaker-metrics",
     "sagemaker-runtime",
     "savingsplans",
+    "scheduler",
     "schemas",
     "sdb",
     "secretsmanager",
     "securityhub",
+    "securitylake",
     "serverlessrepo",
     "service-quotas",
     "servicecatalog",
@@ -320,6 +374,7 @@ ServiceName = Literal[
     "sesv2",
     "shield",
     "signer",
+    "simspaceweaver",
     "sms",
     "sms-voice",
     "snow-device-management",
@@ -329,6 +384,7 @@ ServiceName = Literal[
     "ssm",
     "ssm-contacts",
     "ssm-incidents",
+    "ssm-sap",
     "sso",
     "sso-admin",
     "sso-oidc",
@@ -342,10 +398,14 @@ ServiceName = Literal[
     "textract",
     "timestream-query",
     "timestream-write",
+    "tnb",
     "transcribe",
     "transfer",
     "translate",
+    "trustedadvisor",
+    "verifiedpermissions",
     "voice-id",
+    "vpc-lattice",
     "waf",
     "waf-regional",
     "wafv2",
@@ -356,6 +416,7 @@ ServiceName = Literal[
     "workmail",
     "workmailmessageflow",
     "workspaces",
+    "workspaces-thin-client",
     "workspaces-web",
     "xray",
 ]
